#include <avr/io.h>
#include <avr/interrupt.h>  /* for sei() */
#include <util/delay.h>     /* for _delay_ms() */
#include <avr/pgmspace.h>   /* required by usbdrv.h */

#include "peri.h"
#include "usbdrv.h"

#define RQ_SET_LED         0
#define RQ_GET_SWITCH      1
#define RQ_GET_ALL_SWITCH  2

/* ------------------------------------------------------------------------- */
/* ----------------------------- USB interface ----------------------------- */
/* ------------------------------------------------------------------------- */
usbMsgLen_t usbFunctionSetup(uint8_t data[8])
{
    usbRequest_t *rq = (void *)data;

    /* declared as static so they stay valid when usbFunctionSetup returns */
    static uint8_t switch_state;
		static uint8_t all_state;	

    if (rq->bRequest == RQ_SET_LED)
    {
        uint8_t led_state = rq->wValue.bytes[0];
        uint8_t led_no  = rq->wIndex.bytes[0];
        set_led(led_no, led_state);
        return 0;
    }

    else if (rq->bRequest == RQ_GET_SWITCH)
    {		
				uint8_t sw_no = rq->wIndex.bytes[0];
				if(sw_no == 0){
					switch_state = SWITCH0;
				}else if(sw_no ==1){
        	switch_state = SWITCH1;
				}else if(sw_no ==2){
        	switch_state = SWITCH2;
				}else if(sw_no ==3){
        	switch_state = SWITCH3;
				}else if(sw_no ==4){
        	switch_state = SWITCH4;
				}	
        /* point usbMsgPtr to the data to be returned to host */
        usbMsgPtr = &switch_state;
        /* return the number of bytes of data to be returned to host */
        return 1;
    }else if(rq->bRequest == RQ_GET_ALL_SWITCH){
				uint8_t new = 0;
				new |= (SWITCH0)|(SWITCH1<<1)|(SWITCH2<<2)|(SWITCH3<<3)|(SWITCH4<<4);
				all_state = new;
				usbMsgPtr = &all_state;
				return 1;
		}
		return 0;
    /* default for not implemented requests: return no data back to host */
}

/* ------------------------------------------------------------------------- */
int main(void)
{
    init_peri();

    usbInit();

    /* enforce re-enumeration, do this while interrupts are disabled! */
    usbDeviceDisconnect();
    _delay_ms(300);
    usbDeviceConnect();

    /* enable global interrupts */
    sei();

    /* main event loop */
		

    for(;;)
    {
        usbPoll();
				/*if(SWITCH4){
					set_led(4,1);
					_delay_ms(300);
					set_led(4,0);
				}	
				if(SWITCH3){
					set_led(3,1);
					_delay_ms(300);
					set_led(3,0);
				}
				if(SWITCH2){
					set_led(2,1);
					_delay_ms(300);
					set_led(2,0);
				}
				if(SWITCH1){
					set_led(1,1);
					_delay_ms(300);
					set_led(1,0);
				}
				if(SWITCH0){
					set_led(0,1);
					_delay_ms(300);
					set_led(0,0);
				}*/

    }

    return 0;
}

/* ------------------------------------------------------------------------- */
