from practicum import find_mcu_boards, McuBoard, PeriBoard
from time import sleep
import random
import math
import simpleaudio as sa
import pygame
import sys


def turn_off():
    for event in pygame.event.get():
        if event.type == pygame.QUIT:
            pygame.display.quit()
            pygame.quit()
            peri.set_led(0,0)
            peri.set_led(1,0)
            peri.set_led(2,0)
            peri.set_led(3,0)
            peri.set_led(4,0)
            sys.exit()

def count_down():
    screen.fill(white)
    screen.blit(c3,c3r)
    pygame.display.update()
    turn_off()
    sleep(1)
    screen.blit(c2,c2r)
    pygame.display.update()
    turn_off()
    sleep(1)
    screen.blit(c1,c1r)
    pygame.display.update()
    turn_off()
    sleep(1)

def draw_4_circle():
    for i in range(1,5):
        pygame.draw.circle(screen,grey,(int(width/5*i),int(hight/2)),50)

devs = find_mcu_boards()

if len(devs) == 0:
    print("*** No practicum board found.")
    exit(1)

mcu = McuBoard(devs[0])
print("*** Practicum board found")
print("*** Manufacturer: %s" % \
        mcu.handle.getString(mcu.device.iManufacturer, 256))
print("*** Product: %s" % \
        mcu.handle.getString(mcu.device.iProduct, 256))
peri = PeriBoard(mcu)


width = 600
hight = 300
white =(255,255,255)
red =(255,0,0)
grey =(150,150,150)
green =(0,255,0)
yellow=(238,203,45)
black=(0,0,0)

screen = pygame.display.set_mode((width,hight))
pygame.display.set_caption('Perfect Pitch')
screen.fill(white)

pygame.font.init()

font = pygame.font.Font('freesansbold.ttf', 32)
count =pygame.font.Font('freesansbold.ttf',64)

project = font.render('Perfect Pitch',True,red,white)
pro_r=project.get_rect()
pro_r.center =(width/2,hight/3)

start = font.render('Press to Start',True,black,white)
strect=start.get_rect()
strect.center =(width/2,hight/3*2)

c3 = count.render('3',True,red,white)
c3r=c3.get_rect()
c3r.center =(width/2,hight/2)


c2 = count.render('2',True,red,white)
c2r=c2.get_rect()
c2r.center =(width/2,hight/2)

c1 = count.render('1',True,red,white)
c1r=c1.get_rect()
c1r.center =(width/2,hight/2)


c0 = count.render('Answer',True,red,white)
c0r=c0.get_rect()
c0r.center =(width/2,hight/2)

right=font.render('Correct',True,green,white)
r_r=right.get_rect()
r_r.center =(width/2,hight/4)


wrong=font.render('Incorrect',True,red,white)
w_r=wrong.get_rect()
w_r.center =(width/2,hight/4)

error=font.render('Please choose only one choice',True,yellow,white)
e_r=error.get_rect()
e_r.center =(width/2,hight/4)

res=font.render('Press to Restart',True,black,white)
re_r=res.get_rect()
re_r.center =(width/2,hight/4*3)



pygame.display.flip()

note_dic={"c.wav":"C","c#.wav":"C#","d.wav":"D","e.wav":"E","eb.wav":"Eb","f.wav":"F","f#.wav":"F#","g.wav":"G","g#.wav":"G#","a.wav":"A","b.wav":"B","bb.wav":"Bb"}

notes=["c.wav","c#.wav","d.wav","e.wav","eb.wav","f.wav","f#.wav","g.wav","g#.wav","a.wav","b.wav","bb.wav"]
screen.fill(white)
screen.blit(start,strect)
screen.blit(project,pro_r)
pygame.display.update()
while True:
    peri.set_led(0,0)
    peri.set_led(1,0)
    peri.set_led(2,0)
    peri.set_led(3,0)
    peri.set_led(4,0)
    while(peri.get_switch(4) == False):
        peri.set_led(4,1)
        sleep(0.3)
        peri.set_led(4,0)
        sleep(0.3)
        turn_off()
    peri.set_led(4,1)
    count_down()
    screen.fill(white)
    draw_4_circle()
    pygame.display.update()
    turn_off()

    random.shuffle(notes)
    for i in range(4):
        peri.set_led(i,1)
        pygame.draw.circle(screen,green,(int(width/5*(i+1)),int(hight/2)),50)
        pygame.display.update()        
        wave_obj=sa.WaveObject.from_wave_file('sound/'+notes[i])
        play_obj=wave_obj.play()
        play_obj.wait_done()
        sleep(0.2)
        peri.set_led(i,0)
        pygame.draw.circle(screen,grey,(int(width/5*(i+1)),int(hight/2)),50)
        pygame.display.update()        
        sleep(0.3)
        turn_off()
    ans = random.randint(0,3)
    count_down() 
    screen.blit(c0,c0r)
    pygame.display.update()
    wave_obj=sa.WaveObject.from_wave_file('sound/'+notes[ans])
    play_obj=wave_obj.play()
    play_obj.wait_done()
 
    while(peri.get_all_switch() == 0):
        turn_off()
    screen.fill(white)
    draw_4_circle()
    sw_state=peri.get_all_switch()
    sleep(1)
    if(sw_state in [1,2,4,8] ):
        if (sw_state == math.pow(2,ans)):
            print("Correct")
            screen.blit(right,r_r)
        else:
            print("Wrong") 
            if(sw_state==1):
                w=1
            elif(sw_state==2):
                w=2
            elif(sw_state==4):
                w=3
            elif(sw_state==8):
                w=4
            screen.blit(wrong,w_r)
            pygame.draw.circle(screen,red,(int(width/5*w),int(hight/2)),50)
    else:
        print("Please choose only one from 4 choices")
        screen.blit(error,e_r)

    pygame.draw.circle(screen,green,(int(width/5*(ans+1)),int(hight/2)),50)
    for i in range(1,5):
        n=font.render(note_dic[notes[i]],True,black)
        nr=n.get_rect()
        nr.center=(width/5*i,hight/2)
        screen.blit(n,nr)
    screen.blit(res,re_r)
    pygame.display.update()
    peri.set_led(ans,1)
    while(peri.get_switch(4)==False):
        sw_state=peri.get_all_switch()
        if(sw_state==1):
            wave_obj=sa.WaveObject.from_wave_file('sound/'+notes[0])
            play_obj=wave_obj.play()
            play_obj.wait_done()
        elif(sw_state==2):
            wave_obj=sa.WaveObject.from_wave_file('sound/'+notes[1])
            play_obj=wave_obj.play()
            play_obj.wait_done()
        elif(sw_state==4):
            wave_obj=sa.WaveObject.from_wave_file('sound/'+notes[2])
            play_obj=wave_obj.play()
            play_obj.wait_done()
        elif(sw_state==8):
            wave_obj=sa.WaveObject.from_wave_file('sound/'+notes[3])
            play_obj=wave_obj.play()
            play_obj.wait_done()
        turn_off()


